==> inv-api-1.4.0.50-20240802.052727-1-sources.jar: com/elitesland/inv/dto/invTrn/InvTrnDRpcDTO.java <==
package com.elitesland.inv.dto.invTrn;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

@Data
@ApiModel(description = "库存转移详情")
public class InvTrnDRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单明细ID")
    private Long id;

    @ApiModelProperty("商品id")
    private Long itemId;

    @ApiModelProperty("批次")
    private String lotNo;

    @ApiModelProperty("出库批次")
    private String outLotNo;

    @ApiModelProperty("入库批次")
    private String inLotNo;

    @ApiModelProperty("计划数量")
    private BigDecimal qty;

    @ApiModelProperty("出库数量")
    private BigDecimal outQty;

    @ApiModelProperty("入库数量")
    private BigDecimal inQty;

    @ApiModelProperty("单位")
    private String uom;

    @ApiModelProperty("出库存状态")
    private String outLimit1;

    @ApiModelProperty("计划入库存状态")
    private String planInLimit1;

    @ApiModelProperty("入库存状态")
    private String inLimit1;

    @ApiModelProperty("生产日期")
    private LocalDateTime manuDate;

    @ApiModelProperty("过期日期")
    private LocalDateTime expireDate;

    @ApiModelProperty("关联明细id")
    private Long relateDocDid;

    /**
     * 主表ID
     */
    @ApiModelProperty("主表ID")
    private Long masId;

    /**
     * 行号
     */
    @ApiModelProperty("行号")
    private BigDecimal lineNo;

}

==> inv-api-1.4.6-20240813.140600-1-sources.jar: com/elitesland/inv/dto/invTrn/InvTrnDRpcDTO.java <==
package com.elitesland.inv.dto.invTrn;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

@Data
@ApiModel(description = "库存转移详情")
public class InvTrnDRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单明细ID")
    private Long id;

    @ApiModelProperty("商品id")
    private Long itemId;

    @ApiModelProperty("批次")
    private String lotNo;

    @ApiModelProperty("出库批次")
    private String outLotNo;

    @ApiModelProperty("入库批次")
    private String inLotNo;

    @ApiModelProperty("计划数量")
    private BigDecimal qty;

    @ApiModelProperty("出库数量")
    private BigDecimal outQty;

    @ApiModelProperty("计划数量（辅单位）")
    private BigDecimal qty2;

    @ApiModelProperty("出库数量（辅单位）")
    private BigDecimal outQty2;

    @ApiModelProperty("入库数量")
    private BigDecimal inQty;

    @ApiModelProperty("入库数量（辅单位）")
    private BigDecimal inQty2;

    @ApiModelProperty("单位")
    private String uom;

    @ApiModelProperty("辅单位")
    private String uom2;

    @ApiModelProperty("出库存状态")
    private String outLimit1;

    @ApiModelProperty("计划入库存状态")
    private String planInLimit1;

    @ApiModelProperty("入库存状态")
    private String inLimit1;

    @ApiModelProperty("生产日期")
    private LocalDateTime manuDate;

    @ApiModelProperty("过期日期")
    private LocalDateTime expireDate;

    @ApiModelProperty("关联明细id")
    private Long relateDocDid;

    /**
     * 主表ID
     */
    @ApiModelProperty("主表ID")
    private Long masId;

    /**
     * 行号
     */
    @ApiModelProperty("行号")
    private BigDecimal lineNo;

}
